#include "readLine.h"

int readLine (char * positionInLine, FILE * input_stream) {
  int current_char;
  while (((current_char = fgetc(input_stream)) != EOF) && (current_char != '\n')) {
    * positionInLine = current_char;
    positionInLine++;
  }
  positionInLine = '\0';
  if (current_char == EOF)
    return 0;
  return 1;
}
