#include <gtk/gtk.h>
#include "interface.h"
#include "support.h"
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include "readLine.h"

void read_config (GtkWidget * window1) ;
